{
  config,
  pkgs,
  ...
}:
{
  imports = [
    ./hardware-configuration.nix

    ../common/global
    ../common/users/julian

    # ../common/optional/openssh.nix
    # ../common/optional/greetd.nix
    ../common/optional/pipewire.nix
    ../common/optional/remote-builder.nix
    ../common/optional/boot-efi.nix
    ../common/optional/pcmanfm.nix
    ../common/optional/i3.nix
    ../common/optional/gdm.nix
    ../common/optional/redshift.nix
    ../common/optional/virtualbox.nix
    ../common/optional/xdg-portal.nix
    ../common/optional/polkit.nix # TODO: maybe not needed!
    ../common/optional/keyring.nix # TODO: maybe not needed!
  ];

  networking.hostName = "kardorf"; # Define your hostname.
  networking.networkmanager.enable = true;
  services.resolved.enable = true;

  time.timeZone = "Europe/Berlin";

  boot.loader.efi.efiSysMountPoint = "/boot/efi";
  services.xserver.videoDrivers = [ "nvidia" ];
  hardware.nvidia.package = config.boot.kernelPackages.nvidiaPackages.legacy_470;
  # hardware.nvidia.modesetting.enable = true; # for wayland

  # Enable CUPS to print documents.
  # hardware.sane.enable = true;
  services.printing.enable = true;
  services.printing.browsing = true;
  # services.avahi.enable = true;
  # services.avahi.nssmdns = true;
  services.printing.drivers = with pkgs; [ gutenprint ];

  # List services that you want to enable:
  services.openssh.enable = false;
  services.flatpak.enable = true;
  # Smart card reader
  services.pcscd.enable = true;

  virtualisation.docker.enable = true;

  # Packages needed as root
  environment.systemPackages = with pkgs; [
    vim
    htop
    mc
    gparted-xhost # needs to be installed as system package so it can be actually opened
  ];

  # ======================== DO NOT CHANGE THIS ========================
  system.stateVersion = "22.11";
  # ======================== DO NOT CHANGE THIS ========================
}
